@@ -3,8 +3,6 @@ from ansible.module_utils.hashivault import hashivault_argspec
 from ansible.module_utils.hashivault import hashivault_auth_client
 from ansible.module_utils.hashivault import hashivault_init
 from ansible.module_utils.hashivault import hashiwrapper
-from hvac.constants.ldap import DEFAULT_GROUP_FILTER
-import json
 
 ANSIBLE_METADATA = {'status': ['stableinterface'], 'supported_by': 'community', 'version': '1.1'}
 DOCUMENTATION = '''
@@ -15,48 +13,6 @@ short_description: Hashicorp Vault ldap configuration module
 description:
     - Module to configure the LDAP authentication method in Hashicorp Vault.
 options:
-    url:
-        description:
-            - url for vault
-        default: to environment variable VAULT_ADDR
-    ca_cert:
-        description:
-            - "path to a PEM-encoded CA cert file to use to verify the Vault server TLS certificate"
-        default: to environment variable VAULT_CACERT
-    ca_path:
-        description:
-            - "path to a directory of PEM-encoded CA cert files to verify the Vault server TLS certificate : if ca_cert
-             is specified, its value will take precedence"
-        default: to environment variable VAULT_CAPATH
-    client_cert:
-        description:
-            - "path to a PEM-encoded client certificate for TLS authentication to the Vault server"
-        default: to environment variable VAULT_CLIENT_CERT
-    client_key:
-        description:
-            - "path to an unencrypted PEM-encoded private key matching the client certificate"
-        default: to environment variable VAULT_CLIENT_KEY
-    verify:
-        description:
-            - "if set, do not verify presented TLS certificate before communicating with Vault server : setting this
-             variable is not recommended except during testing"
-        default: to environment variable VAULT_SKIP_VERIFY
-    authtype:
-        description:
-            - "authentication type to use: token, userpass, github, ldap, approle"
-        default: token
-    token:
-        description:
-            - token for vault
-        default: to environment variable VAULT_TOKEN
-    username:
-        description:
-            - username to login to vault.
-        default: to environment variable VAULT_USER
-    password:
-        description:
-            - password to login to vault.
-        default: to environment variable VAULT_PASSWORD
     mount_point:
         description:
             - location where this auth_method is mounted. also known as "path"
@@ -133,7 +89,7 @@ options:
         description:
             - LDAP search base to use for group membership search
         default: ''
-
+extends_documentation_fragment: hashivault
 '''
 EXAMPLES = '''
 ---
@@ -147,8 +103,6 @@ EXAMPLES = '''
         insecure_tls: "{{ auth_ldap_insecure_tls }}"
         group_filter: "{{ auth_ldap_groupfilter }}"
         upn_domain: "{{ auth_ldap_upndomain }}"
-        token: "{{ vault_token }}"
-        url: "{{ vault_url }}"
 '''
 
 
@@ -170,7 +124,7 @@ def main():
     argspec['discover_dn'] = dict(required=False, type='bool', default=False)
     argspec['deny_null_bind'] = dict(required=False, type='bool', default=True)
     argspec['upn_domain'] = dict(required=False, type='str', default='')
-    argspec['group_filter'] = dict(required=False, type='str', default=DEFAULT_GROUP_FILTER)
+    argspec['group_filter'] = dict(required=False, type='str')
     argspec['group_attr'] = dict(required=False, type='str', default='cn')
     argspec['group_dn'] = dict(required=False, type='str', default='')
     module = hashivault_init(argspec, supports_check_mode=True)
